import java.io.FileReader;
import java.io.FileWriter;
import java.io.IOException;
import java.io.PrintWriter;
import java.util.*;

public class Interact {
    private static final String fileName = "gasorposorp";

    static Random rnd;
    final Scanner stdin;
    final Scanner fin;
    final PrintWriter fout;
    final PrintWriter stdout;

    Interact(String inputFileName, String outputFileName) throws IOException {
        stdin = new Scanner(System.in);
        fin = new Scanner(new FileReader(inputFileName));
        fout = new PrintWriter(new FileWriter(outputFileName), true);
        stdout = new PrintWriter(System.out);
    }

    void close() {
        fin.close();
        fout.close();
        stdout.close();
    }

    
    static abstract class InteractorException extends Exception {
        InteractorException(String s) {
            super(s);
        }
    }

    static class WA extends InteractorException {
        WA(String s) {
            super(s);
        }
    }

    static class OK extends InteractorException {
        OK(String s) {
            super(s);
        }
    }

    static class PE extends InteractorException {
        PE(String s) {
            super(s);
        }
    }

    static class FAIL extends InteractorException {
        FAIL(String s) {
            super(s);
        }
    }

    static interface E {
        InteractorException e(String s) throws InteractorException;
    }

    static final E wa = new E() {
        @Override
        public InteractorException e(String s) throws WA {
            throw new WA(s);
        }
    };

    static final E pe = new E() {
        @Override
        public InteractorException e(String s) throws PE {
            throw new PE(s);
        }
    };

    static final E fail = new E() {
        @Override
        public InteractorException e(String s) throws FAIL {
            throw new FAIL(s);
        }
    };

    static final E ok = new E() {
        @Override
        public InteractorException e(String s) throws InteractorException {
            throw new OK(s);
        }
    };

    void go() throws InteractorException {
        int n = fin.nextInt();
        int m = fin.nextInt();
        int k = fin.nextInt();
        boolean[] win = new boolean[n + 1];
        win[1] = false;
        for (int i = 2; i <= n; i++) {
            win[i] = false;
            for (int j = Math.max(1, i - m); j < i; j++) {
                if (!win[j]) {
                    win[i] = true;
                    break;
                }
            }
        }

        int previousNumber = n;
        int cnt = 1;
        Random rndsr = new Random(9847921739817L);
        while (true) {
            String sx = stdin.next();
            if (sx.equals("I'm giving up")) {
                if (!win[n] && k % 2 == 0) {
                    ok.e("ok, lost");
                } else {
                    wa.e("Participant could win, but lost");
                }
            }
            int x = -1;
            try {
                x = Integer.parseInt(sx);
            } catch (Exception e) {
                pe.e("Expected integer, but found " + sx);
            }
            if (previousNumber < x || x < previousNumber - m) {
                pe.e(String.format("Expected number in [%d, %d], but found %d", previousNumber - m, previousNumber, x));
            }
            if (x == previousNumber) {
                cnt++;
            } else {
                cnt = 1;
            }
            if (cnt == k) {
                pe.e(String.format("Number %d repeated k=%d times", x, k));
            }
            if (x == 1 && cnt == k - 1) {
                stdout.println("I'm giving up");
                stdout.flush();
                ok.e("ok, won");
            }
            List<Integer> loosingPositions = new ArrayList<>();
            for (int i = x - 1; i >= Math.max(x - m, 1); i--) {
                if (!win[i]) {
                    loosingPositions.add(i);
                }
            }
            if (!win[x] && cnt + 1 < k) {
                loosingPositions.add(x);
            }
            if (!loosingPositions.isEmpty()) {
                int val = loosingPositions.get(rndsr.nextInt(loosingPositions.size()));
                stdout.println(val);
                stdout.flush();
                cnt += (val == x ? 1 : 0);
                previousNumber = val;
            } else {
                int l = Math.max(1, x - m);
                int r = x - 1;
                if (cnt + 1 < k) {
                    r++;
                }
                if (l > r) {
                    stdout.println("I'm giving up");
                    stdout.flush();
                    ok.e("ok, won");
                } else {
                    int val = l + rndsr.nextInt(r - l + 1);
                    stdout.println(val);
                    stdout.flush();
                    cnt += (val == x ? 1 : 0);
                    previousNumber = val;
                }
            }
        }
    }

    public static void main(String[] args) {
        Locale.setDefault(Locale.US);
        Interact instance = null;
        try {
            instance = new Interact(
                    args.length >= 2 ? args[0] : fileName + ".in",
                    args.length >= 2 ? args[1] : fileName + ".out");
            instance.go();
        } catch (InteractorException e) {
            instance.fout.print(e.getClass().getSimpleName() + " ");
            instance.fout.println(e.getMessage());
        } catch (NumberFormatException e) {
            instance.fout.print("PE ");
            instance.fout.println(e.getMessage());
        } catch (IOException e) {
            instance.fout.print("FAIL ");
            instance.fout.println(e.getMessage());
        } catch (Exception e) {
            instance.fout.print("FAIL ");
            instance.fout.println("Something went wrong: " + e.getMessage());
        }
        instance.close();
    }

}
